/* Copyright (c) 2007 Patrick Mansfield <patmans@us.ibm.com> */
#ifndef _SYS_SCHED_H
#define _SYS_SCHED_H

#include <sys/cdefs.h>

_BEGIN_STD_C

int sched_yield(void);

_END_STD_C

#endif
